@@ -2,11 +2,16 @@
 """Track Earth satellites given TLE data, using up-to-date 2020 SGP4 routines.
 
 This package compiles the official C++ code from `Revisiting Spacetrack
-Report #3 <https://celestrak.org/publications/AIAA/2006-6753/>`_ (AIAA
-2006-6753) and uses it to compute the positions of satellites in Earth
-orbit.  Orbital elements can be read from either a legacy TLE file or
-from a modern OMM element set, both of which you can fetch from a site
-like `CelesTrak <https://celestrak.com/>`_.
+Report #3`_ (AIAA 2006-6753) — specifically, the 2023 May 09 release
+from David Vallado’s `Fundamentals of Astrodynamics and Applications`_
+webpage — and uses it to compute the positions of satellites in Earth
+orbit.  Satellite orbital elements can be loaded from either a legacy
+TLE file or from a modern OMM element set, both of which you can fetch
+from a site like `CelesTrak <https://celestrak.com/>`_.
+
+.. _Revisiting Spacetrack Report #3: https://celestrak.org/publications/AIAA/2006-6753/
+
+.. _Fundamentals of Astrodynamics and Applications: https://celestrak.org/software/vallado-sw.php
 
 If your machine can’t install or compile the C++ code, then this package
 falls back to using a slower pure-Python implementation of SGP4.  Tests
@@ -47,7 +52,7 @@ True
 This library uses the same function names as the official C++ code, to
 help users who are already familiar with SGP4 in other languages.  Here
 is how to compute the x,y,z position and velocity for the International
-Space Station at 12:50:19 on 29 June 2000:
+Space Station at 20:42:00 on 2019 December 9:
 
 >>> from sgp4.api import Satrec
 >>>
@@ -55,14 +60,14 @@ Space Station at 12:50:19 on 29 June 2000:
 >>> t = '2 25544  51.6439 211.2001 0007417  17.6667  85.6398 15.50103472202482'
 >>> satellite = Satrec.twoline2rv(s, t)
 >>>
->>> jd, fr = 2458827, 0.362605
+>>> jd, fr = 2458826.5, 0.8625
 >>> e, r, v = satellite.sgp4(jd, fr)
 >>> e
 0
 >>> print(r)  # True Equator Mean Equinox position (km)
-(-6102.44..., -986.33..., -2820.31...)
+(-6088.92..., -936.13..., -2866.44...)
 >>> print(v)  # True Equator Mean Equinox velocity (km/s)
-(-1.45..., -5.52..., 5.10...)
+(-1.525..., -5.538..., 5.068...)
 
 As input, you can provide either:
 
@@ -107,11 +112,11 @@ If your application does not natively handle Julian dates, you can
 compute ``jd`` and ``fr`` from calendar dates using ``jday()``.
 
 >>> from sgp4.api import jday
->>> jd, fr = jday(2019, 12, 9, 12, 0, 0)
+>>> jd, fr = jday(2019, 12, 9, 20, 42, 0)
 >>> jd
 2458826.5
 >>> fr
-0.5
+0.8625
 
 Double-checking your TLE lines
 ------------------------------
@@ -615,6 +620,10 @@ https://pypi.org/project/sgp4/1.4/
 Changelog
 ---------
 
+2023-10-01 — 2.23
+
+* Tweaked tests to resolve breakage introduced by Python 3.12.
+
 2023-04-27 — 2.22
 
 * Added a ``satnum_str`` attribute, exposing the fact that the C++ now
@@ -702,4 +711,4 @@ Changelog
 | 2012-08-27 — 1.0 — Initial release
 
 """
-__version__ = '2.22'
+__version__ = '2.23'
